# -*- coding: utf-8 -*-
#
# ===================================================================
# The contents of this file are dedicated to the public domain.  To
# the extent that dedication to the public domain is not available,
# everyone is granted a worldwide, perpetual, royalty-free,
# non-exclusive license to exercise all rights associated with the
# contents of this file for any purpose whatsoever.
# No rights are reserved.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
# BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
# ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
# ===================================================================

# This file exists for backward compatibility with old code that refers to
# Crypto.Hash.SHA

from Crypto.Hash.SHA1 import __doc__, new, block_size, digest_size



from typing import Union, Optional

Buffer = Union[bytes, bytearray, memoryview]

class SHA3_256_Hash(object):
    digest_size: int
    oid: str
    def __init__(self, data: Optional[Buffer], update_after_digest: bool) -> None: ...
    def update(self, data: Buffer) -> SHA3_256_Hash: ...
    def digest(self) -> bytes: ...
    def hexdigest(self) -> str: ...
    def new(self) -> SHA3_256_Hash: ...

def new(__data: Buffer = ..., update_after_digest: bool = ...) -> SHA3_256_Hash: ...

digest_size: int
